@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream_ssl.c,v 1.67 2008/09/01 05:50:22 colinleroy Exp $
+ * $Id: mailstream_ssl.c,v 1.68 2008/10/05 14:30:38 colinleroy Exp $
  */
 
 /*
@@ -399,6 +399,7 @@ static int mailstream_gnutls_client_cert_cb(gnutls_session session,
 {
 	struct mailstream_ssl_context * ssl_context = (struct mailstream_ssl_context *)gnutls_session_get_ptr(session);
 	gnutls_certificate_type type = gnutls_certificate_type_get(session);
+
 	st->ncerts = 0;
 
 	if (ssl_context == NULL)
@@ -410,9 +411,8 @@ static int mailstream_gnutls_client_cert_cb(gnutls_session session,
 		st->cert.x509 = &(ssl_context->client_x509);
 		st->key.x509 = ssl_context->client_pkey;
 		st->deinit_all = 0;
-		return 0;
 	}
-	return -1;
+	return 0;
 }
 
 static struct mailstream_ssl_data * ssl_data_new(int fd, void (* callback)(struct mailstream_ssl_context * ssl_context, void * cb_data), void * cb_data)
