@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildirdriver_cached.c,v 1.17 2006/06/26 11:50:26 hoa Exp $
+ * $Id: maildirdriver_cached.c,v 1.21 2008/02/20 22:15:50 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,7 +41,7 @@
 
 #include <stdio.h>
 #include <sys/types.h>
-#ifndef _MSC_VER
+#ifndef WIN32
 #	include <dirent.h>
 #	include <unistd.h>
 #	include <sys/mman.h>
@@ -110,7 +110,6 @@ static int get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
 static mailsession_driver local_maildir_cached_session_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
    /* sess_name */ "maildir-cached",
 
   /* sess_initialize */ initialize,
@@ -156,56 +155,7 @@ static mailsession_driver local_maildir_cached_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
-  /* sess_login_sasl */ NULL,
-
-#else
-  .sess_name = "maildir-cached",
-
-  .sess_initialize = initialize,
-  .sess_uninitialize = uninitialize,
-
-  .sess_parameters = parameters,
-
-  .sess_connect_stream = NULL,
-  .sess_connect_path = connect_path,
-  .sess_starttls = NULL,
-  .sess_login = NULL,
-  .sess_logout = logout,
-  .sess_noop = NULL,
-
-  .sess_build_folder_name = NULL,
-  .sess_create_folder = NULL,
-  .sess_delete_folder = NULL,
-  .sess_rename_folder = NULL,
-  .sess_check_folder = check_folder,
-  .sess_examine_folder = NULL,
-  .sess_select_folder = NULL,
-  .sess_expunge_folder = expunge_folder,
-  .sess_status_folder = status_folder,
-  .sess_messages_number = messages_number,
-  .sess_recent_number = recent_number,
-  .sess_unseen_number = unseen_number,
-  .sess_list_folders = NULL,
-  .sess_lsub_folders = NULL,
-  .sess_subscribe_folder = NULL,
-  .sess_unsubscribe_folder = NULL,
-
-  .sess_append_message = append_message,
-  .sess_append_message_flags = append_message_flags,
-  .sess_copy_message = NULL,
-  .sess_move_message = NULL,
-
-  .sess_get_messages_list = get_messages_list,
-  .sess_get_envelopes_list = get_envelopes_list,
-  .sess_remove_message = NULL,
-#if 0
-  .sess_search_messages = maildriver_generic_search_messages,
-#endif
-
-  .sess_get_message = get_message,
-  .sess_get_message_by_uid = get_message_by_uid,
-  .sess_login_sasl = NULL,
-#endif
+  /* sess_login_sasl */ NULL
 };
 
 mailsession_driver * maildir_cached_session_driver =
@@ -721,7 +671,7 @@ static int get_messages_list(mailsession * session,
   
   for(i = 0 ; i < carray_count(env_list->msg_tab) ; i ++) {
     mailmessage * msg;
-    uint32_t index;
+    uint32_t indx;
     
     msg = carray_get(env_list->msg_tab, i);
     
@@ -738,8 +688,8 @@ static int get_messages_list(mailsession * session,
           msg->msg_uid, strlen(msg->msg_uid));
     }
     else {
-      memcpy(&index, value, sizeof(index));
-      msg->msg_index = index;
+      memcpy(&indx, value, sizeof(indx));
+      msg->msg_index = indx;
     }
   }
   
@@ -892,7 +842,7 @@ static int get_envelopes_list(mailsession * session,
   
   r = mail_cache_db_open_lock(filename_env, &cache_db_env);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
   
@@ -961,7 +911,7 @@ static int get_envelopes_list(mailsession * session,
 
     if (msg->msg_fields != NULL) {
       if (!msg->msg_cached) {
-        /* msg->index is the numerical UID of the message */
+        /* msg->msg_uid is the numerical UID of the message */
 	r = write_cached_envelope(cache_db_env, mmapstr,
             session, msg->msg_uid, msg->msg_fields);
       }
@@ -1131,7 +1081,7 @@ static int get_message_by_uid(mailsession * session,
   void * value;
   size_t value_len;
   struct maildir_cached_session_state_data * data;
-  uint32_t index;
+  uint32_t indx;
   
   data = get_cached_data(session);
   
@@ -1157,7 +1107,7 @@ static int get_message_by_uid(mailsession * session,
     goto close_db;
   }
   
-  memcpy(&index, value, sizeof(index));
+  memcpy(&indx, value, sizeof(indx));
   
   mail_cache_db_close_unlock(filename, uid_db);
 
@@ -1191,7 +1141,7 @@ static int get_message_by_uid(mailsession * session,
   }
   
   r = mailmessage_init(msg, session, maildir_cached_message_driver,
-      index, stat_info.st_size);
+      indx, stat_info.st_size);
   if (r != MAIL_NO_ERROR) {
     mailmessage_free(msg);
     res = r;
