@@ -30,14 +30,18 @@
  */
 
 /*
- * $Id: mboxdriver_cached.c,v 1.50 2005/08/15 11:08:40 hoa Exp $
+ * $Id: mboxdriver_cached.c,v 1.56 2008/02/17 13:13:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mboxdriver_cached.h"
 
 #include <stdio.h>
 #include <string.h>
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #else
 #	include <dirent.h>
@@ -69,7 +73,7 @@ static void mboxdriver_cached_uninitialize(mailsession * session);
 static int mboxdriver_cached_parameters(mailsession * session,
 					int id, void * value);
 
-static int mboxdriver_cached_connect_path(mailsession * session, char * path);
+static int mboxdriver_cached_connect_path(mailsession * session, const char * path);
 
 static int mboxdriver_cached_logout(mailsession * session);
 
@@ -77,21 +81,21 @@ static int mboxdriver_cached_check_folder(mailsession * session);
 
 static int mboxdriver_cached_expunge_folder(mailsession * session);
 
-static int mboxdriver_cached_status_folder(mailsession * session, char * mb,
+static int mboxdriver_cached_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen);
-static int mboxdriver_cached_messages_number(mailsession * session, char * mb,
+static int mboxdriver_cached_messages_number(mailsession * session, const char * mb,
 					     uint32_t * result);
-static int mboxdriver_cached_recent_number(mailsession * session, char * mb,
+static int mboxdriver_cached_recent_number(mailsession * session, const char * mb,
 					   uint32_t * result);
-static int mboxdriver_cached_unseen_number(mailsession * session, char * mb,
+static int mboxdriver_cached_unseen_number(mailsession * session, const char * mb,
 					   uint32_t * result);
 
 static int mboxdriver_cached_append_message(mailsession * session,
-					    char * message, size_t size);
+					    const char * message, size_t size);
 
 static int mboxdriver_cached_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags);
+    const char * message, size_t size, struct mail_flags * flags);
 
 static int
 mboxdriver_cached_get_messages_list(mailsession * session,
@@ -112,7 +116,6 @@ static int mboxdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mbox_cached_session_driver = {
-#if defined (_MSC_VER) || defined (__SUNPRO_CC)
   /* sess_name */ "mbox-cached",
 
   /* sess_initialize */ mboxdriver_cached_initialize,
@@ -159,57 +162,7 @@ static mailsession_driver local_mbox_cached_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
-  /* sess_login_sasl */ NULL,
-
-#else
-  .sess_name = "mbox-cached",
-
-  .sess_initialize = mboxdriver_cached_initialize,
-  .sess_uninitialize = mboxdriver_cached_uninitialize,
-
-  .sess_parameters = mboxdriver_cached_parameters,
-
-  .sess_connect_path = mboxdriver_cached_connect_path,
-  .sess_connect_stream = NULL,
-  .sess_starttls = NULL,
-  .sess_login = NULL,
-  .sess_logout = mboxdriver_cached_logout,
-  .sess_noop = NULL,
-
-  .sess_build_folder_name = NULL,
-  .sess_create_folder = NULL,
-  .sess_delete_folder = NULL,
-  .sess_rename_folder = NULL,
-  .sess_check_folder = mboxdriver_cached_check_folder,
-  .sess_examine_folder = NULL,
-  .sess_select_folder = NULL,
-  .sess_expunge_folder = mboxdriver_cached_expunge_folder,
-  .sess_status_folder = mboxdriver_cached_status_folder,
-  .sess_messages_number = mboxdriver_cached_messages_number,
-  .sess_recent_number = mboxdriver_cached_recent_number,
-  .sess_unseen_number = mboxdriver_cached_unseen_number,
-  .sess_list_folders = NULL,
-  .sess_lsub_folders = NULL,
-  .sess_subscribe_folder = NULL,
-  .sess_unsubscribe_folder = NULL,
-
-  .sess_append_message = mboxdriver_cached_append_message,
-  .sess_append_message_flags = mboxdriver_cached_append_message_flags,
-  
-  .sess_copy_message = NULL,
-  .sess_move_message = NULL,
-
-  .sess_get_messages_list = mboxdriver_cached_get_messages_list,
-  .sess_get_envelopes_list = mboxdriver_cached_get_envelopes_list,
-  .sess_remove_message = mboxdriver_cached_remove_message,
-#if 0
-  .sess_search_messages = maildriver_generic_search_messages,
-#endif
-
-  .sess_get_message = mboxdriver_cached_get_message,
-  .sess_get_message_by_uid = mboxdriver_cached_get_message_by_uid,
-  .sess_login_sasl = NULL,
-#endif
+  /* sess_login_sasl */ NULL
 };
 
 mailsession_driver * mbox_cached_session_driver =
@@ -441,7 +394,7 @@ static int mboxdriver_cached_parameters(mailsession * session,
 
 
 static int get_cache_directory(mailsession * session,
-			       char * path, char ** result)
+			       const char * path, char ** result)
 {
   char * quoted_mb;
   char dirname[PATH_MAX];
@@ -642,7 +595,7 @@ static int read_max_uid_value(mailsession * session, uint32_t * result)
   return res;
 }
 
-static int mboxdriver_cached_connect_path(mailsession * session, char * path)
+static int mboxdriver_cached_connect_path(mailsession * session, const char * path)
 {
   int r;
   int res;
@@ -814,7 +767,7 @@ static int mboxdriver_cached_expunge_folder(mailsession * session)
   return res;
 }
 
-static int mboxdriver_cached_status_folder(mailsession * session, char * mb,
+static int mboxdriver_cached_status_folder(mailsession * session, const char * mb,
     uint32_t * result_messages, uint32_t * result_recent,
     uint32_t * result_unseen)
 {
@@ -920,14 +873,14 @@ static int mboxdriver_cached_status_folder(mailsession * session, char * mb,
   return res;
 }
 
-static int mboxdriver_cached_messages_number(mailsession * session, char * mb,
+static int mboxdriver_cached_messages_number(mailsession * session, const char * mb,
 					     uint32_t * result)
 {
   return mailsession_messages_number(get_ancestor(session), mb, result);
 }
 
 
-static int mboxdriver_cached_recent_number(mailsession * session, char * mb,
+static int mboxdriver_cached_recent_number(mailsession * session, const char * mb,
 					   uint32_t * result)
 {
   uint32_t messages;
@@ -944,7 +897,7 @@ static int mboxdriver_cached_recent_number(mailsession * session, char * mb,
   return MAIL_NO_ERROR;  
 }
 
-static int mboxdriver_cached_unseen_number(mailsession * session, char * mb,
+static int mboxdriver_cached_unseen_number(mailsession * session, const char * mb,
 					   uint32_t * result)
 {
   uint32_t messages;
@@ -965,14 +918,14 @@ static int mboxdriver_cached_unseen_number(mailsession * session, char * mb,
 /* messages operations */
 
 static int mboxdriver_cached_append_message(mailsession * session,
-					    char * message, size_t size)
+					    const char * message, size_t size)
 {
   return mboxdriver_cached_append_message_flags(session,
       message, size, NULL);
 }
 
 static int mboxdriver_cached_append_message_flags(mailsession * session,
-    char * message, size_t size, struct mail_flags * flags)
+    const char * message, size_t size, struct mail_flags * flags)
 {
   int r;
   struct mailmbox_folder * folder;
@@ -1204,7 +1157,7 @@ mboxdriver_cached_get_envelopes_list(mailsession * session,
 
   r = mail_cache_db_open_lock(filename_env, &cache_db_env);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
 
@@ -1270,7 +1223,7 @@ mboxdriver_cached_get_envelopes_list(mailsession * session,
   
   r = mail_cache_db_open_lock(filename_env, &cache_db_env);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
 
