@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mhdriver.c,v 1.35 2006/12/13 18:31:31 hoa Exp $
+ * $Id: mhdriver.c,v 1.38 2008/02/20 22:15:50 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,7 +41,9 @@
 
 #include <stdio.h>
 #include <sys/types.h>
-#ifndef _MSC_VER
+#ifdef WIN32
+#	include "win_etpan.h"
+#else
 #	include <dirent.h>
 #	include <unistd.h>
 #	include <sys/mman.h>
@@ -116,7 +118,6 @@ static int mhdriver_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mh_session_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "mh",
 
   /* sess_initialize */ mhdriver_initialize,
@@ -162,56 +163,7 @@ static mailsession_driver local_mh_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
-  /* sess_login_sasl */ NULL,
-
-#else
-  .sess_name = "mh",
-
-  .sess_initialize = mhdriver_initialize,
-  .sess_uninitialize = mhdriver_uninitialize,
-
-  .sess_parameters = NULL,
-
-  .sess_connect_stream = NULL,
-  .sess_connect_path = mhdriver_connect_path,
-  .sess_starttls = NULL,
-  .sess_login = NULL,
-  .sess_logout = mhdriver_logout,
-  .sess_noop = NULL,
-
-  .sess_build_folder_name = mhdriver_build_folder_name,
-  .sess_create_folder = mhdriver_create_folder,
-  .sess_delete_folder = mhdriver_delete_folder,
-  .sess_rename_folder = mhdriver_rename_folder,
-  .sess_check_folder = NULL,
-  .sess_examine_folder = NULL,
-  .sess_select_folder = mhdriver_select_folder,
-  .sess_expunge_folder = NULL,
-  .sess_status_folder = mhdriver_status_folder,
-  .sess_messages_number = mhdriver_messages_number,
-  .sess_recent_number = mhdriver_messages_number,
-  .sess_unseen_number = mhdriver_messages_number,
-  .sess_list_folders = mhdriver_list_folders,
-  .sess_lsub_folders = mhdriver_lsub_folders,
-  .sess_subscribe_folder = mhdriver_subscribe_folder,
-  .sess_unsubscribe_folder = mhdriver_unsubscribe_folder,
-
-  .sess_append_message = mhdriver_append_message, 
-  .sess_append_message_flags = mhdriver_append_message_flags,
-  .sess_copy_message = mhdriver_copy_message,
-  .sess_move_message = mhdriver_move_message,
-
-  .sess_get_messages_list = mhdriver_get_messages_list,
-  .sess_get_envelopes_list = maildriver_generic_get_envelopes_list,
-  .sess_remove_message = mhdriver_remove_message,
-#if 0
-  .sess_search_messages = maildriver_generic_search_messages,
-#endif
-
-  .sess_get_message = mhdriver_get_message,
-  .sess_get_message_by_uid = mhdriver_get_message_by_uid,
-  .sess_login_sasl = NULL,
-#endif
+  /* sess_login_sasl */ NULL
 };
 
 mailsession_driver * mh_session_driver = &local_mh_session_driver;
@@ -893,7 +845,7 @@ static int mhdriver_get_message_by_uid(mailsession * session,
     const char * uid,
     mailmessage ** result)
 {
-  uint32_t index;
+  uint32_t indx;
   char *p;
   struct mailmh_msg_info * mh_msg_info;
   struct mh_session_state_data * mh_data;
@@ -906,16 +858,13 @@ static int mhdriver_get_message_by_uid(mailsession * session,
   if (uid == NULL)
     return MAIL_ERROR_INVAL;
 
-  index = strtoul(uid, &p, 10);
+  indx = strtoul(uid, &p, 10);
   if (p == uid || * p != '-')
     return MAIL_ERROR_INVAL;
   
   mh_data = session->sess_data;
-#if 0
-  mh_msg_info = cinthash_find(mh_data->mh_cur_folder->fl_msgs_hash, index);
-#endif
-  key.data = &index;
-  key.len = sizeof(index);
+  key.data = &indx;
+  key.len = sizeof(indx);
   r = chash_get(mh_data->mh_cur_folder->fl_msgs_hash, &key, &data);
   if (r < 0)
     return MAIL_ERROR_MSG_NOT_FOUND;
@@ -932,7 +881,7 @@ static int mhdriver_get_message_by_uid(mailsession * session,
     size_p = p + 1;
     size = strtoul(size_p, &p, 10);
     if ((* p == '\0') && (size == mh_msg_info->msg_size))
-      return mhdriver_get_message(session, index, result);
+      return mhdriver_get_message(session, indx, result);
   }
   else if (* p != '-') {
     return MAIL_ERROR_INVAL;
