@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3driver_cached.c,v 1.47 2006/06/26 11:50:27 hoa Exp $
+ * $Id: pop3driver_cached.c,v 1.49 2008/02/17 13:13:27 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -128,7 +128,6 @@ static int pop3driver_cached_login_sasl(mailsession * session,
     const char * password, const char * realm);
 
 static mailsession_driver local_pop3_cached_session_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "pop3-cached",
 
   /* sess_initialize */ pop3driver_cached_initialize,
@@ -174,56 +173,7 @@ static mailsession_driver local_pop3_cached_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
-  /* sess_login_sasl */ pop3driver_cached_login_sasl,
-  
-#else
-  .sess_name = "pop3-cached",
-
-  .sess_initialize = pop3driver_cached_initialize,
-  .sess_uninitialize = pop3driver_cached_uninitialize,
-
-  .sess_parameters = pop3driver_cached_parameters,
-
-  .sess_connect_stream = pop3driver_cached_connect_stream,
-  .sess_connect_path = NULL,
-  .sess_starttls = pop3driver_cached_starttls,
-  .sess_login = pop3driver_cached_login,
-  .sess_logout = pop3driver_cached_logout,
-  .sess_noop = pop3driver_cached_noop,
-
-  .sess_build_folder_name = NULL,
-  .sess_create_folder = NULL,
-  .sess_delete_folder = NULL,
-  .sess_rename_folder = NULL,
-  .sess_check_folder = pop3driver_cached_check_folder,
-  .sess_examine_folder = NULL,
-  .sess_select_folder = NULL,
-  .sess_expunge_folder = pop3driver_cached_expunge_folder,
-  .sess_status_folder = pop3driver_cached_status_folder,
-  .sess_messages_number = pop3driver_cached_messages_number,
-  .sess_recent_number = pop3driver_cached_recent_number,
-  .sess_unseen_number = pop3driver_cached_unseen_number,
-  .sess_list_folders = NULL,
-  .sess_lsub_folders = NULL,
-  .sess_subscribe_folder = NULL,
-  .sess_unsubscribe_folder = NULL,
-
-  .sess_append_message = NULL,
-  .sess_append_message_flags = NULL,
-  .sess_copy_message = NULL,
-  .sess_move_message = NULL,
-
-  .sess_get_messages_list = pop3driver_cached_get_messages_list,
-  .sess_get_envelopes_list = pop3driver_cached_get_envelopes_list,
-  .sess_remove_message = pop3driver_cached_remove_message,
-#if 0
-  .sess_search_messages = maildriver_generic_search_messages,
-#endif
-
-  .sess_get_message = pop3driver_cached_get_message,
-  .sess_get_message_by_uid = pop3driver_cached_get_message_by_uid,
-  .sess_login_sasl = pop3driver_cached_login_sasl,
-#endif
+  /* sess_login_sasl */ pop3driver_cached_login_sasl
 };
 
 mailsession_driver * pop3_cached_session_driver =
@@ -468,7 +418,7 @@ static int pop3driver_cached_expunge_folder(mailsession * session)
 
   r = mail_cache_db_open_lock(filename_flags, &cache_db_flags);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto err;
   }
 
@@ -545,7 +495,7 @@ static int pop3driver_cached_status_folder(mailsession * session,
 
   r = mail_cache_db_open_lock(filename_flags, &cache_db_flags);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto err;
   }
 
@@ -788,7 +738,7 @@ pop3driver_cached_get_envelopes_list(mailsession * session,
 
   r = mail_cache_db_open_lock(filename_env, &cache_db_env);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
 
@@ -797,7 +747,7 @@ pop3driver_cached_get_envelopes_list(mailsession * session,
 
   r = mail_cache_db_open_lock(filename_flags, &cache_db_flags);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto close_db_env;
   }
 
@@ -851,13 +801,13 @@ pop3driver_cached_get_envelopes_list(mailsession * session,
   
   r = mail_cache_db_open_lock(filename_env, &cache_db_env);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
   
   r = mail_cache_db_open_lock(filename_flags, &cache_db_flags);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto close_db_env;
   }
 
