@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_sender.c,v 1.28 2006/05/22 13:39:41 hoa Exp $
+ * $Id: mailimap_sender.c,v 1.29 2006/10/20 00:13:30 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -169,11 +169,6 @@ static int mailimap_set_item_send(mailstream * fd,
 				  struct mailimap_set_item * item);
 
 
-static int mailimap_set_send(mailstream * fd,
-			     struct mailimap_set * set);
-
-
-
 static int mailimap_status_att_send(mailstream * fd, int * status_att);
 
 
@@ -2467,7 +2462,7 @@ static int mailimap_set_item_send(mailstream * fd,
   }
 }
 
-static int mailimap_set_send(mailstream * fd,
+int mailimap_set_send(mailstream * fd,
     struct mailimap_set * set)
 {
   return mailimap_struct_list_send(fd, set->set_list, ',',
